==> boinc_5.8.17.orig.tar.gz: boinc-5.8.17.orig/doc/papers.php <==
<?php
require_once("docutil.php");
page_head("Papers related to BOINC");
echo"

<h2>Popular articles</h2>
<ul>
<li>
<a href=boinc2.pdf>Public Computing: Reconnecting People to Science<a>.
David P. Anderson.
Conference on Shared Knowledge and the Web.
Residencia de Estudiantes, Madrid, Spain, Nov. 17-19 2003.
(A paper about BOINC's goals.
Also available in
<a href=madrid.html>HTML</a>
<a href=http://boinc.de/madrid_de.htm>HTML/German</a>
<a href=http://www.seti.nl/content.php?c=boinc_berkeley_madrid>HTML/Dutch</a>
<a href=http://boinc.oocp.org/madrid.html>Japanese</a>).

<li>
<a href=distributing_science_final.pdf>Distributing Science</a>,
by D. Carroll, C. Rahmlow, T. Psiaki, and G. Wojtaszczyk, July 2005.
</ul>

<h2>Technical papers about BOINC</h2>

<ul>
<li>
<a href=http://boinc.berkeley.edu/boinc_papers/sched/paper.pdf>Local Scheduling for Volunteer Computing</a>.
David P. Anderson and John McLeod VII.
Workshop on Large-Scale, Volatile Desktop Grids (PCGrid 2007)
held in conjunction with the IEEE International Parallel & Distributed Processing Symposium (IPDPS), March 30, 2007, Long Beach.
<li>
<a href=http://boinc.berkeley.edu/boinc_papers/api/text.pdf>Designing a Runtime System for Volunteer Computing</a>.
David P. Anderson, Carl Christensen and Bruce Allen.
Supercomputing '06 (The International Conference for
High Performance Computing, Networking, Storage and Analysis), Tampa, November 2006.

<li>
<a href=http://boinc.berkeley.edu/boinc_papers/internet/paper.pdf>The Computational and Storage Potential of Volunteer Computing</a>.
David P. Anderson and Gilles Fedak
IEEE/ACM International Symposium on Cluster Computing and the Grid,
Singapore, May 16-19, 2006.

<li>
<a href=server_perf.pdf>High-Performance Task Distribution for Volunteer Computing</a>.
David P. Anderson, Eric Korpela, Rom Walton
First IEEE International Conference on e-Science and Grid Technologies.
5-8 December 2005, Melbourne

<li>
<a href=http://csdl2.computer.org/persagen/DLAbsToc.jsp?resourcePath=/dl/proceedings/ipdps/&toc=comp/proceedings/ipdps/2005/2312/02/2312toc.xml&DOI=10.1109/IPDPS.2005.247>Homogeneous Redundancy: a Technique to Ensure Integrity of Molecular Simulation Results Using Public Computing</a>.
M. Taufer, D. Anderson, P. Cicotti, C.L. Brooks III.
From 19th IEEE International Parallel and Distributed Processing Symposium (IPDPS'05) Heterogeneous Computing Workshop.
April 4 2005, Denver CO.
<li>
<a href=http://www.fatbat.dk/thesis/>
Developing Distributed Computing Solutions Combining Grid Computing and
Public Computing</a>.
Jakob Gregor Pedersen & Christian Ulrik S&oslash;ttrup.
Master's thesis from University of Copenhagen.
March 2005.
(Describes tools for transparently moving jobs between Condor and BOINC.)

<li>
<a href=grid_paper_04.pdf>BOINC: A System for Public-Resource Computing and Storage</a>.
David P. Anderson.
5th IEEE/ACM International Workshop on Grid Computing.
November 8, 2004, Pittsburgh, USA.
<br>
(Also available in
<a href=http://boinc.oocp.org/grid_paper_04.html>Japanese</a>)

</ul>
<h2>Project-specific papers</h2>
<ul>
<li>
<a href=http://www.climateprediction.net/science/pubs/cpdn-computing.pdf>The Challenge of Volunteer Computing With Lengthy Climate Model Simulations</a>.
Carl Christensen, Tolu Aina and David Stainforth.
First IEEE International Conference on e-Science and Grid Technologies.
5-8 December 2005, Melbourne
<li>
<a href=rosetta_ms.doc>Reporting@Home:  Delivering Dynamic Graphical Feedback to Participants in Community Computing Projects</a>.
Stuart Ozer, David E. Kim, David Baker
(in preparation).

</ul>
<h2>Powerpoint</h2>
<ul>
<li> <a href=https://uimon.cern.ch/twiki/pub/LHCAtHome/LinksAndDocs/boincciemat06.pdf>A BOINC seminar by Juan Antonio Lopez Perez of CERN</a>,
presented at CIEMAT in Madrid, November 2005.
Also available in a
<a href=https://uimon.cern.ch/twiki/pub/LHCAtHome/LinksAndDocs/boincciematprint06.pdf>print version</a>.

</ul>
";
page_tail();
?>

==> boinc_5.10.45.orig.tar.gz: boinc-5.10.45.orig/doc/papers.php <==
<?php
require_once("docutil.php");
page_head("Papers and talks BOINC");
echo"

<h2>Slides from talks on BOINC</h2>
<ul>
<li> <a href=talks/ipdps_07_kn.ppt>Volunteer Computing: Planting the Flag</a>,
keynote address at the PCGrid 2007 workshop held at the IPDPS conference,
March 30, 2007.
<li> <a href=talks/ipdps_07_sched.ppt>Talk on client scheduling</a>
at the PCGrid 2007 workshop held at the IPDPS conference, March 30, 2007.
<li> <a href=talks/singapore_public.pdf>A Million Years of Computing</a>,
talk at the Singapore National Library, May 2006.
<li> <a href=talks/condor_boinc_06.ppt>Talk at Condor Week</a>
, Madison WI, April 2006.
</ul>
<h2>Popular articles</h2>
<ul>
<li>
<a href=boinc2.pdf>Public Computing: Reconnecting People to Science<a>.
David P. Anderson.
Conference on Shared Knowledge and the Web.
Residencia de Estudiantes, Madrid, Spain, Nov. 17-19 2003.
(A paper about BOINC's goals.
Also available in
<a href=madrid.html>HTML</a>
<a href=http://boinc.de/madrid_de.htm>HTML/German</a>
<a href=http://www.seti.nl/content.php?c=boinc_berkeley_madrid>HTML/Dutch</a>
<a href=http://boinc.oocp.org/madrid.html>Japanese</a>).

<li>
<a href=distributing_science_final.pdf>Distributing Science</a>,
by D. Carroll, C. Rahmlow, T. Psiaki, and G. Wojtaszczyk, July 2005.
</ul>

<h2>Technical papers</h2>

<ul>
<li>
<a href=http://boinc.berkeley.edu/boinc_papers/sched/paper.pdf>Local Scheduling for Volunteer Computing</a>.
David P. Anderson and John McLeod VII.
Workshop on Large-Scale, Volatile Desktop Grids (PCGrid 2007)
held in conjunction with the IEEE International Parallel & Distributed Processing Symposium (IPDPS), March 30, 2007, Long Beach.
<li>
<a href=http://boinc.berkeley.edu/boinc_papers/api/text.pdf>Designing a Runtime System for Volunteer Computing</a>.
David P. Anderson, Carl Christensen and Bruce Allen.
Supercomputing '06 (The International Conference for
High Performance Computing, Networking, Storage and Analysis), Tampa, November 2006.

<li>
<a href=http://boinc.berkeley.edu/boinc_papers/internet/paper.pdf>The Computational and Storage Potential of Volunteer Computing</a>.
David P. Anderson and Gilles Fedak
IEEE/ACM International Symposium on Cluster Computing and the Grid,
Singapore, May 16-19, 2006.

<li>
<a href=server_perf.pdf>High-Performance Task Distribution for Volunteer Computing</a>.
David P. Anderson, Eric Korpela, Rom Walton
First IEEE International Conference on e-Science and Grid Technologies.
5-8 December 2005, Melbourne

<li>
<a href=http://csdl2.computer.org/persagen/DLAbsToc.jsp?resourcePath=/dl/proceedings/ipdps/&toc=comp/proceedings/ipdps/2005/2312/02/2312toc.xml&DOI=10.1109/IPDPS.2005.247>Homogeneous Redundancy: a Technique to Ensure Integrity of Molecular Simulation Results Using Public Computing</a>.
M. Taufer, D. Anderson, P. Cicotti, C.L. Brooks III.
From 19th IEEE International Parallel and Distributed Processing Symposium (IPDPS'05) Heterogeneous Computing Workshop.
April 4 2005, Denver CO.
<li>
<a href=http://www.fatbat.dk/thesis/>
Developing Distributed Computing Solutions Combining Grid Computing and
Public Computing</a>.
Jakob Gregor Pedersen & Christian Ulrik S&oslash;ttrup.
Master's thesis from University of Copenhagen.
March 2005.
(Describes tools for transparently moving jobs between Condor and BOINC.)

<li>
<a href=grid_paper_04.pdf>BOINC: A System for Public-Resource Computing and Storage</a>.
David P. Anderson.
5th IEEE/ACM International Workshop on Grid Computing.
November 8, 2004, Pittsburgh, USA.
<br>
(Also available in
<a href=http://boinc.oocp.org/grid_paper_04.html>Japanese</a>)

</ul>
<h2>Project-specific papers</h2>
<ul>
<li>
<a href=http://www.climateprediction.net/science/pubs/cpdn-computing.pdf>The Challenge of Volunteer Computing With Lengthy Climate Model Simulations</a>.
Carl Christensen, Tolu Aina and David Stainforth.
First IEEE International Conference on e-Science and Grid Technologies.
5-8 December 2005, Melbourne
<li>
<a href=rosetta_ms.doc>Reporting@Home:  Delivering Dynamic Graphical Feedback to Participants in Community Computing Projects</a>.
Stuart Ozer, David E. Kim, David Baker
(in preparation).

</ul>
";
page_tail();
?>
